external

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 11, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BackOffRetry

func BackOffRetry(ctx context.Context, l zerolog.Logger, maxTime time.Duration, retryFn func() error) error

func CallWithTimeout added in v0.3.5

func CallWithTimeout[T any](ctx context.Context, timeout time.Duration, fn func() (T, error)) (T, error)

CallWithTimeout executes a function with a timeout and returns the result or an error if it times out

Types

type ConnectionStatus added in v0.6.0

type ConnectionStatus int
const (
	// Connection is connected
	StatusConnected ConnectionStatus = iota
	// Connection is disconnected and not trying to reconnect
	StatusDisconnected
	// Connection is attempting to reconnect
	StatusReconnecting
	// Connection cannot authentified itself to the db
	StatusNotAuthenticated
	// Connection is purposfully closed
	StatusClosed
)

func (ConnectionStatus) String added in v0.6.0

func (s ConnectionStatus) String() string

Directories

Path Synopsis

Jump to