Documentation
¶
Index ¶
Constants ¶
const ( HeaderRequestEnconding = "request-encoding" HeaderContentEncoding = "content-encoding" HeaderOriginalTrigger = "original-trigger" HeaderOrigin = "origin" HeaderZstdEncoding = "zstd" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Mir ¶
type Mir struct {
Bus *nats.Conn
LockStore distributed_lock.DistributedLockStore
// contains filtered or unexported fields
}
Expose Mir specific functions and domain Publicly expose nats io connection for custom usage
func Connect ¶
Establish connection to the Mir server This will enable communication to and from the device To properly close the connection, call the Close() function
func (*Mir) Disconnect ¶
Close the connection to the Mir server Release all resources and stop all go routines
func (Mir) GetInstanceName ¶
type Msg ¶
func (Msg) GetOriginalTriggerId ¶
Mainly present for Events Represent the serverId that made the request trigger
type ProtoCmdDesc ¶
type SendDeviceConfigRequestJson ¶ added in v0.2.0
type SendDeviceConfigRequestProto ¶ added in v0.2.0
Click to show internal directories.
Click to hide internal directories.